# ***kaparoo-lightning-package***



<!-- [              MARKDOWN BADGES              ] -->

<!-- [              MARKDOWN BADGES              ] -->

|||
|---|---|
|**Environment**| [![Lightning](https://img.shields.io/badge/-Lightning%202.0+-792ee5?logo=pytorchlightning&logoColor=white)](https://github.com/Lightning-AI/lightning) [![Python](https://img.shields.io/badge/python-3.10+-blue.svg?)](https://www.python.org/downloads/)|
|**Metadata**| [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) [![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch) [![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) [![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![Gitomoji](https://img.shields.io/badge/gitmoji-%20😜%20😍-FFDD67.svg?style=flat-square")](https://gitmoji.dev)|

<!-- [                    END                    ] -->

<!-- [                    END                    ] -->



<!-- [             TABLE OF CONTENTS             ] -->

<details>
<summary><strong>Table of Contents</strong></summary>

- [***lightning-package***](#lightning-package)
  - [:wave: **Overview**](#wave-overview)
  - [:balance\_scale: **License**](#balance_scale-license)

</details>

<!-- [                    END                    ] -->



## :wave: **Overview**

A Python package for (personally) common and useful features for PyTorch Lightning.

## :balance_scale: **License**

This project is distributed under the terms of [MIT](./LICENSE) license.  
